@@ -40,6 +40,7 @@ class TornadoHTTPClient(CurlAsyncHTTPClient):
         self._user_agent = None
         self.use_cookie = True
         self.debug = False
+        self.verify_ssl = False
 
 
     def set_user_agent(self, user_agent):
@@ -67,6 +68,9 @@ class TornadoHTTPClient(CurlAsyncHTTPClient):
                 curl.setopt(pycurl.COOKIEFILE, COOKIE_FILE)
                 curl.setopt(pycurl.COOKIEJAR, COOKIE_FILE)
 
+            if not self.verify_ssl:
+                curl.setopt(pycurl.SSL_VERIFYPEER, 0)
+
             if self.debug:
                 curl.setopt(pycurl.VERBOSE, 1)
 
